==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Reviews/language/lang-italian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PREVIOUS","Pagina Precedente");
define("_NEXT","Prossima Pagina");
define("_YOURNAME","Tuo Nome");
define("_SORTASC","Ordinamento Ascendente");
define("_SORTDESC","Ordinamento Discendente");
define("_CANCEL","Cancella");
define("_YES","Si");
define("_NO","No");
define("_SCORE","Voto:");
define("_REPLYMAIN","Posta Commento");
define("_ALLOWEDHTML","Tags HTML Abilitati:");
define("_POSTANON","Posta Anonimamente");
define("_WRITEREVIEW","Scrivi Recensione");
define("_WRITEREVIEWFOR","Scrivi Recensione per");
define("_ENTERINFO","Inserisci le informazioni in accordo con le specifiche");
define("_PRODUCTTITLE","Titolo Prodotto");
define("_NAMEPRODUCT","Nome del Prodotto Recensito.");
define("_REVIEW","Recensione");
define("_CHECKREVIEW","La tua attuale recensione. Fai attenzione alla grammatica! Scrivi almeno un centinaio di parole, OK? Se sai come si fa puoi usare anche tags HTML.");
define("_FULLNAMEREQ","Tuo Nome Completo. Richiesto.");
define("_REMAIL","Tuo Email");
define("_REMAILREQ","Tuo indirizzo E-mail. Richiesto.");
define("_SELECTSCORE","Voto per Questo Prodotto");
define("_RELATEDLINK","Link Correlati");
define("_PRODUCTSITE","Sito Ufficiale del Prodotto. Attenzione deve cominciare con \"http://\"");
define("_LINKTITLE","Titolo Link");
define("_LINKTITLEREQ","Richiesto se hai inserito link correlati, altrimenti non richiesto.");
define("_RIMAGEFILE","Nome File Immagine");
define("_RIMAGEFILEREQ","Nome dell'immagine di copertina, deve trovarsi in images/reviews/. Non richiesto.");
define("_CHECKINFO","Assicurati che tutte le informazioni inserite siano corrette al 100% e usano grammatica corretta. Per esempio, non inserire il testo tutto in MAIUSCOLO, potrebbe essere rifiutato.");
define("_INVALIDTITLE","Titolo Non Valido... Non pu&ograve; essere vuoto");
define("_INVALIDSCORE","Voto Non Valido... Deve essere un nukmero da 1 a 10");
define("_INVALIDTEXT","Testo Recensione Non Valido... Non pu&ograve; essere vuoto");
define("_INVALIDHITS","Hits deve essere un numero positivo intero");
define("_CHECKNAME","Devi inserire sia il tuo nome sia il tuo indirizzo email");
define("_INVALIDEMAIL","Email Non Valida (es: you@hotmail.com)");
define("_INVALIDLINK","Devi inserire sia il titolo che il correlato link oppure lasciare vuoti ambedue");
define("_ADDED","Aggiunto:");
define("_REVIEWER","Recensore:");
define("_REVIEWID","Recensione ID");
define("_HITS","Hits");
define("_LOOKSRIGHT","Va bene cos&igrave;?");
define("_RMODIFIED","modificato");
define("_RADDED","aggiunto");
define("_ADMINLOGGED","Correntemente logged come admin... questa recensione deve essere immediatamente");
define("_RTHANKS","Grazie per l'inserimento di questa Recensione");
define("_MODIFICATION","modifiche");
define("_ISAVAILABLE","Non disponibile nel database recensioni.");
define("_EDITORWILLLOOK","L'editore dar&agrave; un'occhiata alla tua inserzione. Presto sar&agrave; disponibile, se accettata!");
define("_RBACK","Torna Indice Recensioni");
define("_RWELCOME","Benvenuto nella Sezione Recensioni");
define("_10MOSTPOP","10 pi&ugrave; popolari");
define("_10MOSTREC","10 pi&ugrave; recenti");
define("_THEREARE","Ci sono");
define("_REVIEWSINDB","Recensioni nel Database");
define("_REVIEWS","Recensioni");
define("_REVIEWSLETTER","Recensioni per lettera");
define("_NOREVIEWS","Non c'&egrave; nessuna Recensione sotto la lettera");
define("_TOTALREVIEWS","Recensioni(e) Totali trovate.");
define("_RETURN2MAIN","Ritorna al Menu Principale");
define("_REVIEWCOMMENT","Commenti sulla Recensione:");
define("_YOURNICK","Tuo Nickname:");
define("_RCREATEACCOUNT","<a href=user.php>Crea</a> nuovo account");
define("_YOURCOMMENT","Tuo Commento:");
define("_MYSCORE","Mio Voto:");
define("_REVIEWMOD","Modifica Recensioni");
define("_RDATE","Data:");
define("_RTITLE","Titolo:");
define("_RTEXT","Testo:");
define("_REVEMAIL","Email:");
define("_RLINK","Link:");
define("_RLINKTITLE","Titolo Link:");
define("_COVERIMAGE","Immagine:");
define("_PREMODS","Anteprima Modifiche");
define("_PAGE","Pagina");
define("_PAGEBREAK","Se desideri pagine multiple inserisci <b>&lt;!--pagebreak--&gt;</b> nei punti di taglio.");
define("_PREVIEW","Anteprima");
define("_LANGUAGE","Lingua");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Reviews/language/lang-italian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PREVIOUS","Pagina Precedente");
define("_NEXT","Prossima Pagina");
define("_YOURNAME","Tuo Nome");
define("_SORTASC","Ordinamento Ascendente");
define("_SORTDESC","Ordinamento Discendente");
define("_CANCEL","Cancella");
define("_YES","Si");
define("_NO","No");
define("_SCORE","Voto:");
define("_REPLYMAIN","Posta Commento");
define("_ALLOWEDHTML","Tags HTML Abilitati:");
define("_POSTANON","Posta Anonimamente");
define("_WRITEREVIEW","Scrivi Recensione");
define("_WRITEREVIEWFOR","Scrivi Recensione per");
define("_ENTERINFO","Inserisci le informazioni in accordo con le specifiche");
define("_PRODUCTTITLE","Titolo Prodotto");
define("_NAMEPRODUCT","Nome del Prodotto Recensito.");
define("_REVIEW","Recensione");
define("_CHECKREVIEW","La tua attuale recensione. Fai attenzione alla grammatica! Scrivi almeno un centinaio di parole, OK? Se sai come si fa puoi usare anche tags HTML.");
define("_FULLNAMEREQ","Tuo Nome Completo. Richiesto.");
define("_REMAIL","Tuo Email");
define("_REMAILREQ","Tuo indirizzo E-mail. Richiesto.");
define("_SELECTSCORE","Voto per Questo Prodotto");
define("_RELATEDLINK","Link Correlati");
define("_PRODUCTSITE","Sito Ufficiale del Prodotto. Attenzione deve cominciare con \"http://\"");
define("_LINKTITLE","Titolo Link");
define("_LINKTITLEREQ","Richiesto se hai inserito link correlati, altrimenti non richiesto.");
define("_RIMAGEFILE","Nome File Immagine");
define("_RIMAGEFILEREQ","Nome dell'immagine di copertina, deve trovarsi in images/reviews/. Non richiesto.");
define("_CHECKINFO","Assicurati che tutte le informazioni inserite siano corrette al 100% e usano grammatica corretta. Per esempio, non inserire il testo tutto in MAIUSCOLO, potrebbe essere rifiutato.");
define("_INVALIDTITLE","Titolo Non Valido... Non pu&ograve; essere vuoto");
define("_INVALIDSCORE","Voto Non Valido... Deve essere un nukmero da 1 a 10");
define("_INVALIDTEXT","Testo Recensione Non Valido... Non pu&ograve; essere vuoto");
define("_INVALIDHITS","Hits deve essere un numero positivo intero");
define("_CHECKNAME","Devi inserire sia il tuo nome sia il tuo indirizzo email");
define("_INVALIDEMAIL","Email Non Valida (es: you@hotmail.com)");
define("_INVALIDLINK","Devi inserire sia il titolo che il correlato link oppure lasciare vuoti ambedue");
define("_ADDED","Aggiunto:");
define("_REVIEWER","Recensore:");
define("_REVIEWID","Recensione ID");
define("_HITS","Hits");
define("_LOOKSRIGHT","Va bene cos&igrave;?");
define("_RMODIFIED","modificato");
define("_RADDED","aggiunto");
define("_ADMINLOGGED","Correntemente logged come admin... questa recensione deve essere immediatamente");
define("_RTHANKS","Grazie per l'inserimento di questa Recensione");
define("_MODIFICATION","modifiche");
define("_ISAVAILABLE","Non disponibile nel database recensioni.");
define("_EDITORWILLLOOK","L'editore dar&agrave; un'occhiata alla tua inserzione. Presto sar&agrave; disponibile, se accettata!");
define("_RBACK","Torna Indice Recensioni");
define("_RWELCOME","Benvenuto nella Sezione Recensioni");
define("_10MOSTPOP","10 pi&ugrave; popolari");
define("_10MOSTREC","10 pi&ugrave; recenti");
define("_THEREARE","Ci sono");
define("_REVIEWSINDB","Recensioni nel Database");
define("_REVIEWS","Recensioni");
define("_REVIEWSLETTER","Recensioni per lettera");
define("_NOREVIEWS","Non c'&egrave; nessuna Recensione sotto la lettera");
define("_TOTALREVIEWS","Recensioni(e) Totali trovate.");
define("_RETURN2MAIN","Ritorna al Menu Principale");
define("_REVIEWCOMMENT","Commenti sulla Recensione:");
define("_YOURNICK","Tuo Nickname:");
define("_RCREATEACCOUNT","<a href=user.php>Crea</a> nuovo account");
define("_YOURCOMMENT","Tuo Commento:");
define("_MYSCORE","Mio Voto:");
define("_REVIEWMOD","Modifica Recensioni");
define("_RDATE","Data:");
define("_RTITLE","Titolo:");
define("_RTEXT","Testo:");
define("_REVEMAIL","Email:");
define("_RLINK","Link:");
define("_RLINKTITLE","Titolo Link:");
define("_COVERIMAGE","Immagine:");
define("_PREMODS","Anteprima Modifiche");
define("_PAGE","Pagina");
define("_PAGEBREAK","Se desideri pagine multiple inserisci <b>&lt;!--pagebreak--&gt;</b> nei punti di taglio.");
define("_PREVIEW","Anteprima");
define("_LANGUAGE","Lingua");

?>
